@@ -17,7 +17,7 @@ def parse_time(time_str):
     :return datetime.timedelta: A datetime.timedelta object
     """
     time_str=time_str.replace(" ","")
-    regex = re.compile(r'^((?P<years>[\.\d]+?)y)?((?P<days>[\.\d]+?)d)?((?P<hours>[\.\d]+?)h)?((?P<minutes>[\.\d]+?)m)?((?P<seconds>[\.\d]+?)s)?$')
+    regex = re.compile(r'^((?P<years>[\.\d]+?)y)?((?P<days>[\.\d]+?)d)?((?P<hours>[\.\d]+?)h)?((?P<minutes>[\.\d]+?)m)?((?P<seconds>[\.\d]+?)s)?((?P<picoseconds>[\.\d]+?)ps)?((?P<kiloyears>[\.\d]+?)ky)?$')
     parts = regex.match(time_str)
     assert parts is not None, "Could not parse any time information from '{}'.  Examples of valid strings: '8h', '2d8h5m20s', '2m4s'".format(time_str)
     time_params = {name: float(param) for name, param in parts.groupdict().items() if param}
@@ -29,6 +29,21 @@ def parse_time(time_str):
         else:
             time_params['days']=days
         del time_params['years']
+    if 'picoseconds' in time_params.keys():
+        days=time_params['picoseconds']*1.15741e-17 #picoseconds to days
+        if 'days' in time_params.keys():
+            time_params['days']+=days
+        else:
+            time_params['days']=days
+        del time_params['picoseconds']
+    if 'kiloyears' in time_params.keys():
+        
+        days=time_params['kiloyears']*1000*year_to_days #kiloyears to days
+        if 'days' in time_params.keys():
+            time_params['days']+=days
+        else:
+            time_params['days']=days
+        del time_params['kiloyears']
     return dt.timedelta(**time_params).total_seconds()
 
 def tryfloat(num):
@@ -73,9 +88,12 @@ class FispactRead:
         try:
             #self.elapsed_time=line.split('ELAPSED TIME IS')[1].split('*')[0].strip()
             time_i=line.split('TIME IS')[1].split('OR')[-1].split('*')[0].strip()
-            time_i2=line.split('ELAPSED TIME IS')[1].split('*')[0].strip()
+            time_i2=line.split('ELAPSED TIME IS')[1].split('*')[0].strip().replace('ps', ' ps').replace('ky', ' ky')
             self.elapsed_time=str(float(time_i.split()[0]))+' '+time_i.split()[1][0].lower()
-            self.elapsed_time2=str(float(time_i2.split()[0]))+' '+time_i2.split()[1][0].lower()
+            if 'ps' not in time_i2 and 'ky' not in time_i2:
+                self.elapsed_time2=str(float(time_i2.split()[0]))+' '+time_i2.split()[1][0].lower()
+            else:
+                self.elapsed_time2=str(float(time_i2.split()[0]))+' '+time_i2.split()[1][0:2].lower()
         except IndexError:
             time_i=line.split('TIME IS')[1].split('OR')[-1].split('*')[0].strip()
             self.elapsed_time=str(float(time_i.split()[0]))+' '+time_i.split()[1][0].lower()
@@ -124,12 +142,15 @@ class FispactRead:
             #df['step_time']=self.elapsed_time
             df['time_label']=self.elapsed_time2 if self.elapsed_time2 is not None else self.elapsed_time
             df['time']=df['time_label'].apply(lambda x: parse_time(x))
+            
+
             df['time_label']=df['time_label'].apply(lambda x: re.sub(r'(\.0)(?=(\s+))','',x))
             df['time_day']=df['time']/(24*3600)
-            df['decay_costant']=df['half_life'].apply(lambda _s: np.log(2)/_s if type(_s)==float else _s)
+            if 'half_life' in df.columns:
+                df['decay_costant']=df['half_life'].apply(lambda _s: np.log(2)/_s if type(_s)==float else _s)
             df['element']=df['nuclide'].apply(lambda x: re.match(r'(?i)[A-Z]+(?=(\d+))',x).group(0))
             return df
-        except:
+        except Exception as e: 
             return None
         
 
@@ -269,7 +290,8 @@ def read_fispact_json(inputfile):
                 data['inventory_data'][i]['cooling'] = 1
                 data['inventory_data'][i]['elapsed_time']=elapsed_time_prev+cool_time - cool_time_prev
             else:
-                print('there is an error')
+                data['inventory_data'][i]['cooling'] = 1
+                data['inventory_data'][i]['elapsed_time']=elapsed_time_prev+cool_time - cool_time_prev
         else:
             if irr_time == 0:
                 data['inventory_data'][i]['elapsed_time']=cool_time
@@ -278,7 +300,8 @@ def read_fispact_json(inputfile):
                 data['inventory_data'][i]['elapsed_time']=irr_time
                 data['inventory_data'][i]['cooling'] = 0
             else:
-                print('there is an error')
+                data['inventory_data'][i]['elapsed_time'] = 0
+                data['inventory_data'][i]['cooling'] = 1
         if data['inventory_data'][i]['nuclides']:
             df=pd.DataFrame(data['inventory_data'][i]['nuclides'])
             df['atoms']=df['grams']/df['isotope']*AVOGADRO
